@@ -22,6 +22,7 @@ class AgeGroupVSD
     double   d_stdDev;      // if negative: std dev not used
 
     static unsigned s_indent;
+    bool d_exp;
 
     public:
         AgeGroupVSD(VaryType varyType, bool useStdDev,
@@ -35,6 +36,8 @@ class AgeGroupVSD
         double value() const;                                           // .f
         double stdDev() const;                                          // .f
 
+        void ln();
+
         void vary();                                                    // 1
 
         static void fmt(unsigned valueIntWidth, unsigned valuePrec,     // inl
