@@ -3,7 +3,7 @@
 
 Costs::Costs()
 :
-    d_base{ "Costs:", "biop:"}
+    d_base{ ""}
 {
     bool lungCancer = not Globals::isBreast();
 
