@@ -3,8 +3,6 @@
 
 void Costs::setAge()
 {
-    // d_base = { "Costs:", "Discount:"}
-
-    d_base.push_back("age:");
+    d_base.back() = "age:";
     Parser::nonNegative(d_base, d_referenceAge);
 }
