@@ -3,7 +3,7 @@
 
 void CT::setSensitivity()
 {
-    auto lines = Parser::any({ "Modalities:", "CT:", "sensitivity:" });
+    auto lines = Parser::any({ "CT:", "sensitivity:" });
 
     bool checkRange = true;
     while (true)
