@@ -6,7 +6,7 @@
 
 void Densities::add(bool *checkRange, LineInfo const &line)
 {
-    ProbGroup density;
+    ProbGroup density{ RANGE };
 
     if (not Parser::extract(line, density))         // density spec. error
     {
@@ -38,7 +38,3 @@ void Densities::add(bool *checkRange, LineInfo const &line)
 
     Err::msgTxt(context);
 }
-
-
-
-
