@@ -28,7 +28,8 @@ std::ostream &Distribution::insert(std::ostream &out) const
 
         default:
             Globals::setWidthPrec(out, s_width, s_precision) <<
-                            d_confValue << " (" << s_name[d_distType] << ')';
+                (d_exp ? exp(d_confValue) : d_confValue) <<
+                    " (" << s_name[d_distType] << ')';
         break;
     }
 
