@@ -1,3 +1,8 @@
+inline Group::Group(Series series)
+:
+    d_series(series)
+{}
+
 inline uint16_t Group::begin() const
 {
     return d_begin;
@@ -9,7 +14,6 @@ inline uint16_t Group::end() const
 }
 
 template <HasGroup Type>
-//template <typename Type>
 bool Group::nextRange(std::vector<Type> const &vect) const
 {
     return  vect.empty()                    // no Type elements yet
@@ -26,5 +30,3 @@ inline bool operator!=(Group const &lhs, Group const &rhs)
 {
     return not (lhs == rhs);
 }
-
-
