@@ -5,6 +5,7 @@
 #include <ostream>
 #include <cstdint>
 
+#include "../enums/enums.h"
 #include "../typedefs/typedefs.h"
 #include "../hasgroup/hasgroup.h"
 
@@ -15,10 +16,14 @@ class Group
     friend std::istream &operator>>(std::istream &in, Group &group);    //  .f
     friend std::ostream &operator<<(std::ostream &out, Group const &group);
 
+    Series      d_series;
+
     uint16_t    d_begin = 0;
     uint16_t    d_end = END_AGE;
 
     public:
+        Group(Series series);                                           // .f
+
         uint16_t begin() const;                                         // .f
         uint16_t end() const;                                           // .f
 
