@@ -3,11 +3,12 @@
 
 Growth::Growth()
 :
-    d_base{ "Tumor:", "Growth:", "" },
+    d_base{ "Growth:", "" },
     d_bc{ Globals::isBreast() },
     d_selfMean(VARY_NONNEG)
 {
-    setStart();
     setSelfDetect();
     setDoublingTime();
+
+    setStart();
 }
