@@ -9,12 +9,12 @@ void Incidence::setIncidence()
 {
     SimulationType simulationType = Globals::simulationType();
 
-    StringVect base{ "Tumor:", "Incidence:" };
+    StringVect base;
 
     switch (simulationType)
     {
         case BREAST:
-            base.resize(4);                         // set [2] and [3] in
+            base.resize(2);                         // set [0] and [1] in
         break;                                      // setincidence2.cc
 
         case MALE:
@@ -26,7 +26,7 @@ void Incidence::setIncidence()
         break;
     }
 
-    if (simulationType != BREAST)
+    if (simulationType != BREAST)                   // LC simulation
     {
         base.push_back("");
         setIncidence(base, 0, false);               // no probability
@@ -34,9 +34,10 @@ void Incidence::setIncidence()
     }
     else
     {
-        for (size_t idx = 0; idx != s_incidence.size(); ++idx)
+                // Breast:, currently: BRCA1:, BRCA2:
+        for (size_t idx = 0, end = Params::nLabels(); idx != end; ++idx)
         {
-            base[2] = s_incidence[idx];
+            base[0] = Params::label(idx);
             setIncidence(base, idx, true);          // set probability
         }
 
