@@ -5,9 +5,9 @@ double Incidence::sumProbs()
 {
     double sumProb = 0;
 
-    for (Params const &params: d_params)
+    for (ParamsPtr const &paramsPtr: d_params)
     {
-        sumProb += params.prob();
+        sumProb += paramsPtr->prob();
         d_cumProb.push_back(sumProb);
     }
 
