@@ -26,7 +26,10 @@ void Loop::genCases(size_t iter, size_t nCases)
         d_totalCost += d_caseCost;
 
         if (dataTable.stream() and (showAll or caseIdx + 1 == nCases))
+        {
+            d_tumor.checkDeath(d_naturalDeathAge);
             writeData(dataTable, caseIdx);
+        }
     }
 
     dataTable << hline();
