@@ -1,8 +1,6 @@
 #define XERR
 #include "loop.ih"
 
-    // -> ORG/niterationsloop.cpp
-
 void Loop::iterate()
 {
     CSVTable sensTable = headerSensitivity();   // table to collect
@@ -10,12 +8,16 @@ void Loop::iterate()
 
     Random::instance().setSeed(d_scenario.seed());
 
+    d_modalities.active();                      // prepare the active Mods.
+
     for (size_t idx = 0, end = d_scenario.nIterations(); idx != end; ++idx)
     {
         ofstream spreadStream;
 
         size_t nCases = cases();
 
+        d_roundBiopCosts.assign(d_nRounds, 0);  // reset the rounds biop costs
+
         Random::instance().reinit(nCases, d_scenario.generatorType());
 
         if (Globals::vary())                    // maybe vary the parameters
@@ -44,3 +46,4 @@ void Loop::iterate()
     if (sensTable.stream())
         sensTable << hline();
 }
+
