@@ -25,7 +25,12 @@ bool Loop::leaving(double screeningAge)
     {
         d_tumor.characteristicsAt(d_naturalDeathAge);
         d_deathAge = d_naturalDeathAge;
-        return left(before1stRound ? UNDETECTED_PRE : UNDETECTED_DURING, 
+        bool died = d_naturalDeathAge < d_tumor.onset();
+        return left(
+                    before1stRound ? 
+                            died ? NATURAL_PRE    : UNDETECTED_PRE 
+                        : 
+                            died ? NATURAL_DURING : UNDETECTED_DURING, 
                     d_naturalDeathAge);
     }
 
