@@ -1,16 +1,10 @@
 #define XERR
 #include "loop.ih"
 
-//      d_pool->falsePositives(d_round * (modality + 1)) >
-//        d_modalities[XRAY][modality == MAMMOGRAPHY ? MAMMO : TOMO]
-//                    [screeningAge >= 40].value()
-
+    // no tumor is present
 
 void Loop::maybeFalsePositive(ModBase *modBase, double screeningAge)
 {
-//xerr("specificity: " << modBase->specificity(screeningAge) << ' ' << \ <--
-//d_costs.usingAt(screeningAge));
-
     double rnd = Random::instance().uniform();
     double spec = modBase->specificity(screeningAge);
 
@@ -26,7 +20,7 @@ void Loop::maybeFalsePositive(ModBase *modBase, double screeningAge)
         ++d_nRoundFP[d_round];
         d_roundInfo[d_round] = FALSE_POSITIVE;
 
-        addCost(d_costs.usingAt(screeningAge));
-//        addCost(d_costs.biopsy(screeningAge));
+            // add the using costs to the case and biop costs
+        d_caseCost += addBiopCosts(d_costs.usingAt(screeningAge));
     }
 }
