@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "loop.ih"
 
 void Loop::writeRounds(CSVTable &tab) const
@@ -8,10 +8,12 @@ void Loop::writeRounds(CSVTable &tab) const
 
     for (size_t rnd = 0; rnd != d_nRounds; ++rnd)
     {
-        tab.more() << rnd <<
+        tab.more() << (rnd + 1) <<          // rounds.txt: natural round nrs
                       d_nRoundFP[rnd] << d_nRoundFN[rnd] <<
-                      d_nDetections[rnd] << d_nIntervals[rnd] <<
-                      d_roundCost[rnd];
+                      d_nDetections[rnd] << 
+                      d_nIntervals[rnd] << d_nTrueIntervals[rnd] << 
+                      static_cast<size_t>(round(d_roundCost[rnd])) <<
+                      static_cast<size_t>(round(d_roundBiopCosts[rnd]));
 
         d_modalities.writeRounds(tab, rnd);
         tab.row();
