@@ -3,6 +3,6 @@
 
 Modalities::~Modalities()
 {
-    for (ModBase *ptr: d_modBase)
-        delete ptr;
+    for (auto modBasePtr: d_modBaseVect)
+        delete modBasePtr;
 }
