@@ -24,7 +24,9 @@ class Modalities
 
     std::vector<ModBase *> d_modBaseVect;   // defined modalities
     StringVect d_modalityIDs;               // and their IDs
-
+    StringSet d_active;                     // the active modalities
+    std::vector<ModBase *> d_activeVect;    // ptrs to active modalities
+    
     public:
         Modalities(Tumor const &tumor);
         ~Modalities();
@@ -38,8 +40,6 @@ class Modalities
                                 // returns UNDEFINED if 'modality' is unknown
         uint16_t find(std::string const &modality) const;
 
-// double specificity(age) const: age may not be negative
-
             // return a vector of ModBase ptrs matching the names specified
             //  in 'active'
         std::vector<ModBase *> use(Uint16Vect const &active) const;
@@ -47,22 +47,26 @@ class Modalities
 
         void vary(std::ostream &out);
 
-// currently not used
-// double const *hasDose(StringVect const &ids) const;
-
         void writeParameters(std::ostream &out) const;
 
-        void roundFmt(FBB::CSVTable &tab) const;
-        void roundHeaders(FBB::CSVTable &tab) const;
+                                                        // determine the Mod. 
+        size_t roundFmt(FBB::CSVTable &tab) const;      // #fields & width   
+
+        void roundHeaders(FBB::CSVTable &tab) const;    // write the Mod names
+                                                        // write the Mod data
         void writeRounds(FBB::CSVTable &tmp, size_t round) const;
 
+        void active();                          // sets d_activeVect
+        void activate(std::string const &modality);       
+
     private:
         void addMod(ModBase *modBase);
 };
 
-inline StringVect const &Modalities::modalityIDs() const
-{
-    return d_modalityIDs;
-}
+// double specificity(age) const: age may not be negative
+// currently not used
+// double const *hasDose(StringVect const &ids) const;
+
+#include "modalities.f"
 
 #endif
