@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "modalities.ih"
 
 void Modalities::resetCounters(size_t nRounds)
