@@ -3,7 +3,7 @@
 
 ModBase::ModBase(string const &id)
 :
-    d_base{ "Modalities:", id + ':', "costs:" },
+    d_base{ id + ':', "costs:" },
     d_id(id),
     d_defined(Parser::hasSection(d_base))
 {
