@@ -3,6 +3,6 @@
 
 void Options::lastCase(string const &value)
 {
-    xerr("value: " << value);
+//    xerr("value: " << value);
     d_lastCase = stoul(value);
 }
