@@ -26,8 +26,8 @@ class Options
 
     std::string d_home;             // current 'HOME' directory
 
-    
-    std::string d_specified[2];     // specified options: 
+
+    std::string d_specified[2];     // specified options:
                                     // [0]: command-line, [1]: analysis
 
     bool d_specificAges = false;
@@ -40,18 +40,18 @@ class Options
 
 
     std::string d_base[2];          // guaranteed to end in '/'
-                                    // [0]: as specified, [1]: as used 
+                                    // [0]: as specified, [1]: as used
                                     // in Analysis: sections
 
-    std::string d_cancer[2];        // [0]: as specified, [1]: as used 
+    std::string d_cancer[2];        // [0]: as specified, [1]: as used
                                     // in Analysis: sections
 
-    std::string d_config[2];        // [0]: as specified, [1]: as used 
+    std::string d_config[2];        // [0]: as specified, [1]: as used
                                     // in Analysis: sections
 
     std::string d_dataFile[2];      // [0]: as specified, [1]: as used
-                                    // after replacing + by base 
-    std::string d_parametersFile[2];    
+                                    // after replacing + by base
+    std::string d_parametersFile[2];
     std::string d_roundsFile[2];
     std::string d_sensitivityFile[2];
 
@@ -62,7 +62,7 @@ class Options
     static std::unordered_map<int, char const *> s_fileName;
 
     static Options *s_options;
-    
+
     public:
         static Options &instance();
 
@@ -84,7 +84,7 @@ class Options
 
         bool specificAges() const;                              // .f
 
-        void fixedNaturalDeathAge(double &deathAge) const; 
+        void fixedNaturalDeathAge(double &deathAge) const;
         void fixedTumorAge(double &tumorAge) const;
         size_t lastCase() const;                                // .f
 
@@ -97,6 +97,8 @@ class Options
 
         void actualize();                       // transform ~ and +
 
+        bool tnm() const;                       // --tnm was specified
+
     private:
         Options();
 
@@ -109,11 +111,13 @@ class Options
         void deathAge(std::string const &value);
         void deathAgeOption(std::string const &value);
 
-        void fileOption(std::string *dest, int option); 
+        void fileOption(std::string *dest, int option);
 
         void lastCase(std::string const &value);
         void lastCaseOption(std::string const &value);
 
+        void logOption(std::string const &value);
+
             // xxx[STARTUP]: as specified, xxx[ANALYSIS]: as used
         void replaceHome(std::string &path);
         void replacePlus(std::string &fname);
@@ -134,4 +138,3 @@ class Options
 #include "options.f"
 
 #endif
-
