@@ -44,5 +44,5 @@ Options::Options()
     if (d_arg.option(&value, "log"))
         logOption(value);
 
-    setSimulationType();
+    setSimulationType();                // 'c'
 }
