@@ -1,14 +1,11 @@
-//#define XERR
+#define XERR
 #include "parser.ih"
 
+    // load the configuration file 'fname'
 void Parser::load(string const &fname)
 {
     ConfigLines lines{ fname };
 
-    addLineInfoVectors(s_map);              // add (empty) LineInfoVects at
-                                            // the map's deepest nesting 
-                                            // levels
-
     vector<Map *> mapPtrVect{ &s_map };     // start loading at the top
 
     while (lines.get())                   // add the parser lines
