@@ -5,5 +5,7 @@ double Random::logNormal(double mean, double stdDev)
 {
     d_logNormal.param(LogNormalParams{ mean, stdDev });
 
-    return d_logNormal(d_engine[LOGNORMAL]);
+    double ret = d_logNormal(d_engine[LOGNORMAL]);
+    g_log('L') << "          logNormal random value: " << ret << nl;
+    return ret;
 }
