@@ -3,7 +3,7 @@
 
 Scenario::Scenario()
 :
-    d_base{ "Scenario:", "" }           // 2nd field set by set-members
+    d_base{ "" }                // 1st field set by set-members
 {
     setNiterations();
     setNcases();
