@@ -3,7 +3,8 @@
 
 void Screening::writeParameters(ostream &out) const
 {
-    Globals::setPrecision(out, 1) <<
+    //Globals::setPrecision(out, 3) <<
+    out <<
         "Screening:\n"
         "  attendanceRate: " << d_rate << "\n"
         "  rounds:         " << d_roundVect.size() << '\n';
@@ -11,5 +12,7 @@ void Screening::writeParameters(ostream &out) const
     for (auto const &round: d_roundVect)
         out << "    " << round << '\n';
 
-    Globals::setPrecision(out, 3).put('\n');
+//    Globals::setPrecision(out, 3).put('\n');
+    out.put('\n');
+
 }
