@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "simulator.ih"
 
 void Simulator::setAnalysisSource()
@@ -28,6 +28,9 @@ void Simulator::setAnalysisSource()
             }
         }
 
+        if (d_next == 0)
+            wmsg << "No Analysis: specification found" << endl;
+
         d_nextSpecs = &Simulator::fileAnalysis;
     }
 }
