@@ -4,7 +4,7 @@
     // load the BC TNM category boundaries
 void Survival::loadBC()
 {
-    auto lines = Parser::one({ "Tumor:", "bc:" });
+    auto lines = Parser::one({ "bc:" });
 
     LineInfo const *lineInfo = lines.get();
 
