@@ -3,7 +3,7 @@
 
 void Survival::loadS3()
 {
-    auto lines = Parser::any({ "Tumor:", "S3:", "prob:" });
+    auto lines = Parser::any({ "prob:" });
 
     bool push = true;
     while (true)
