@@ -3,17 +3,17 @@
 
 Survival::Survival()
 {
-    if (not Globals::isBreast())
+    if (not Globals::isBreast())                // LC simulation
     {
         d_vary = &Survival::varyLung;
         d_write = &Survival::writeLung;
         d_cptVSDrow = &Survival::cptVSDrow;
 
         loadS3();
-        loadS4();
+        loadS4();                               // loads "lung[0-4]"
     }
-    else
-    {
+    else                                        // BC simulation: only 
+    {                                           // type: must be specified
         d_vary = &Survival::varyBreast;
         d_write = &Survival::writeBreast;
         d_cptVSDrow = &Survival::cptTNM;
@@ -21,8 +21,8 @@ Survival::Survival()
         d_vsdMatrix.push_back(                  // load the BC 'type' params
                         Parser::VSDparameters(
                             VARY_MEAN,
-                            { "Tumor:", "Survival:", "type:" },
-                            { 'a', 'b', 'c', 'd' }
+                            { "type:" },
+                            { 'a', 'b', 'c', 'd', 'e' }
                         )
                     );
 
