@@ -1,7 +1,7 @@
 //#define XERR
 #include "tumor.ih"
 
-void Tumor::check(char const *type) const
+void Tumor::requireTumor(char const *type) const
 {
     if (d_selfDetectAge == NO_TUMOR)
         throw Exception{} << "cannot determine tumor " << type <<
