@@ -3,6 +3,6 @@
 
 double Tumor::volume() const
 {
-    check("volume");
+    requireTumor("volume");
     return d_volume;
 }
